@@ -24,7 +24,6 @@
 #include <qpa/qplatformtheme.h>
 
 #include <QHash>
-#include <QObject>
 #include <QKeySequence>
 
 class KHintsSettings;
@@ -34,7 +33,6 @@ class X11Integration;
 class QIconEngine;
 class QWindow;
 
-class AltKeyEventListener;
 
 class KdePlatformTheme : public QPlatformTheme
 {
